@@ -201,7 +201,7 @@ gpm_statistics_add_events_typical (GPtrArray *array)
 				       GPM_GRAPH_WIDGET_SHAPE_CIRCLE,
 				       _("On AC"));
 	gpm_statistics_add_event_type (array, GPM_EVENT_ON_BATTERY,
-				       GPM_COLOUR_DARK_BLUE,
+				       GPM_COLOUR_RED,
 				       GPM_GRAPH_WIDGET_SHAPE_CIRCLE,
 				       _("On battery"));
 	gpm_statistics_add_event_type (array, GPM_EVENT_SESSION_POWERSAVE,
@@ -295,7 +295,7 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("power");
 		*axis_desc_x = g_strdup (_("Time since startup"));
 		*axis_desc_y = g_strdup (_("Power"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("Power"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_GREEN, _("Power"));
 		gpm_statistics_add_events_typical (*key_event);
 		return TRUE;
 	}
@@ -304,7 +304,7 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("time");
 		*axis_desc_x = g_strdup (_("Time since startup"));
 		*axis_desc_y = g_strdup (_("Estimated time"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("Time"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_GREEN, _("Time"));
 		gpm_statistics_add_events_typical (*key_event);
 		return TRUE;
 	}
@@ -313,7 +313,7 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("percentage");
 		*axis_desc_x = g_strdup (_("Time since startup"));
 		*axis_desc_y = g_strdup (_("Battery percentage"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("Percentage"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_GREEN, _("Percentage"));
 		gpm_statistics_add_events_typical (*key_event);
 		return TRUE;
 	}
@@ -331,34 +331,8 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("percentage");
 		*axis_desc_x = g_strdup (_("Battery percentage"));
 		*axis_desc_y = g_strdup (_("Accuracy of reading"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_GREEN, _("Valid data"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("No data"));
-		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
-					       GPM_COLOUR_CYAN,
-					       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
-				 	      _("Start point"));
-		gpm_statistics_add_event_type (*key_event, GPM_EVENT_SUSPEND,
-					       GPM_COLOUR_YELLOW,
-					       GPM_GRAPH_WIDGET_SHAPE_TRIANGLE,
-				 	      _("Stop point"));
-		return TRUE;
-	}
-	if (strcmp (type, "profile-charge-time") == 0) {
-		*axis_type_x = g_strdup ("percentage");
-		*axis_type_y = g_strdup ("time");
-		*axis_desc_x = g_strdup (_("Battery percentage"));
-		*axis_desc_y = g_strdup (_("Average time elapsed"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_GREEN, _("Valid data"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("No data"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("Extrapolated data"));
-		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
-					       GPM_COLOUR_CYAN,
-					       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
-				 	      _("Start point"));
-		gpm_statistics_add_event_type (*key_event, GPM_EVENT_SUSPEND,
-					       GPM_COLOUR_YELLOW,
-					       GPM_GRAPH_WIDGET_SHAPE_TRIANGLE,
-				 	      _("Stop point"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Trusted"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("Untrusted"));
 		return TRUE;
 	}
 	if (strcmp (type, "profile-discharge-accuracy") == 0) {
@@ -366,8 +340,18 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("percentage");
 		*axis_desc_x = g_strdup (_("Battery percentage"));
 		*axis_desc_y = g_strdup (_("Accuracy of reading"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_GREEN, _("Valid data"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("No data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("Trusted"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_BLUE, _("Untrusted"));
+		return TRUE;
+	}
+	if (strcmp (type, "profile-charge-time") == 0) {
+		*axis_type_x = g_strdup ("percentage");
+		*axis_type_y = g_strdup ("time");
+		*axis_desc_x = g_strdup (_("Battery percentage"));
+		*axis_desc_y = g_strdup (_("Average time elapsed"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Valid data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_GREY, _("Extrapolated data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("No data"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
 					       GPM_COLOUR_CYAN,
 					       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
@@ -383,9 +367,9 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("time");
 		*axis_desc_x = g_strdup (_("Battery percentage"));
 		*axis_desc_y = g_strdup (_("Average time elapsed"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_GREEN, _("Valid data"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("No data"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("Extrapolated data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Valid data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_GREY, _("Extrapolated data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("No data"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
 					       GPM_COLOUR_CYAN,
 					       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
@@ -632,7 +616,7 @@ gpm_info_log_do_poll (gpointer data)
 	array = info->priv->collection->primary;
 	unit = gpm_cell_array_get_unit (array);
 
-	if (info->priv->is_laptop == TRUE) {
+	if (info->priv->is_laptop) {
 		/* work out seconds elapsed */
 		value_x = g_timer_elapsed (info->priv->timer, NULL) - GPM_INFO_DATA_POLL;
 
@@ -645,22 +629,18 @@ gpm_info_log_do_poll (gpointer data)
 			colour = GPM_COLOUR_CHARGED;
 		}
 
-		gpm_array_add (info->priv->percentage_data, value_x,
-			       unit->percentage, colour);
-
-		/* sanity check to less than 100W */
-		if (unit->rate < 100000) {
+		if (unit->percentage > 0) {
+			gpm_array_add (info->priv->percentage_data, value_x,
+				       unit->percentage, colour);
+		}
+		if (unit->rate > 0) {
 			gpm_array_add (info->priv->rate_data, value_x,
 				       unit->rate, colour);
 		}
-
-		/* sanity check to less than 10 hours */
-		if (unit->time_discharge < 10*60*60) {
-			gpm_array_add (info->priv->time_data, value_x,
-					   unit->time_discharge, colour);
+		if (unit->voltage > 0) {
+			gpm_array_add (info->priv->voltage_data, value_x,
+				       unit->voltage, colour);
 		}
-		gpm_array_add (info->priv->voltage_data, value_x,
-			       unit->voltage, colour);
 	}
 	return TRUE;
 }
@@ -675,7 +655,7 @@ ac_adapter_changed_cb (GpmAcAdapter *ac_adapter,
 		       gboolean      on_ac,
 		       GpmInfo      *info)
 {
-	if (on_ac == TRUE) {
+	if (on_ac) {
 		gpm_info_event_log (info, GPM_EVENT_ON_AC,
 				    _("AC adapter inserted"));
 	} else {
@@ -857,7 +837,7 @@ gpm_info_init (GpmInfo *info)
 
 	/* set to a blank list */
 	info->priv->events = gpm_array_new ();
-	if (info->priv->is_laptop == TRUE) {
+	if (info->priv->is_laptop) {
 		info->priv->percentage_data = gpm_array_new ();
 		info->priv->rate_data = gpm_array_new ();
 		info->priv->time_data = gpm_array_new ();
@@ -873,7 +853,7 @@ gpm_info_init (GpmInfo *info)
 		info->priv->voltage_data = NULL;
 	}
 
-	if (info->priv->is_laptop == TRUE) {
+	if (info->priv->is_laptop) {
 		/* get the maximum x-axis size from gconf */
 		GpmConf *conf = gpm_conf_new ();
 		guint max_time;
