@@ -59,7 +59,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint	     signals [LAST_SIGNAL] = { 0, };
+static guint	     signals [LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE (GpmInhibit, gpm_inhibit, G_TYPE_OBJECT)
 
@@ -326,7 +326,7 @@ gpm_inhibit_has_inhibit (GpmInhibit *inhibit,
 
 	length = g_slist_length (inhibit->priv->list);
 
-	if (inhibit->priv->ignore_inhibits == TRUE) {
+	if (inhibit->priv->ignore_inhibits) {
 		gpm_debug ("Inhibit ignored through gconf policy!");
 		*has_inihibit = FALSE;
 	}
@@ -365,16 +365,63 @@ gpm_inhibit_get_message (GpmInhibit  *inhibit,
 
 	if (g_slist_length (inhibit->priv->list) == 1) {
 		data = (GpmInhibitData *) g_slist_nth_data (inhibit->priv->list, 0);
-		g_string_append_printf (message, "<b>%s</b> ",
-					data->application);
-		g_string_append_printf (message, _("has stopped the %s from "
-						   "taking place : "),
-					action);
-		g_string_append_printf (message, "<i>%s</i>.",
-					data->reason);
+		gchar *boldstr = g_strdup_printf ("<b>%s</b>", data->application);
+		gchar *italicstr = g_strdup_printf ("<b>%s</b>", data->reason);
+		
+		if (strcmp (action, "suspend") == 0) {
+			/*Translators: first %s is an application name, second %s is the reason*/
+			g_string_append_printf (message, _("%s has stopped the suspend from taking place: %s."),
+				boldstr, italicstr);
+
+		} else if (strcmp (action, "hibernate") == 0) {
+			/*Translators: first %s is an application name, second %s is the reason*/
+			g_string_append_printf (message, _("%s has stopped the hibernate from taking place: %s."),
+					boldstr, italicstr); 
+
+		} else if (strcmp (action, "policy action") == 0) {
+			/*Translators: first %s is an application name, second %s is the reason*/
+			g_string_append_printf (message, _("%s has stopped the policy action from taking place: %s."),
+					boldstr, italicstr); 
+
+		} else if (strcmp (action, "reboot") == 0) {
+			/*Translators: first %s is an application name, second %s is the reason*/
+			g_string_append_printf (message, _("%s has stopped the reboot from taking place: %s."),
+					boldstr, italicstr); 
+
+		} else if (strcmp (action, "shutdown") == 0) {
+			/*Translators: first %s is an application name, second %s is the reason*/
+			g_string_append_printf (message, _("%s has stopped the shutdown from taking place: %s."),
+				boldstr, italicstr); 
+
+		} else if (strcmp (action, "timeout action") == 0) {
+			/*Translators: first %s is an application name, second %s is the reason*/
+			g_string_append_printf (message, _("%s has stopped the timeout action from taking place: %s."),
+				boldstr, italicstr); 
+		}
+
+		g_free (boldstr);
+		g_free (italicstr);
+
 	} else {
-		g_string_append_printf (message, _("Multiple applications have stopped the "
-					"%s from taking place."), action);
+		if (strcmp (action, "suspend") == 0) {
+			g_string_append (message, _("Multiple applications have stopped the suspend from taking place."));
+
+		} else if (strcmp (action, "hibernate") == 0) {
+			g_string_append (message, _("Multiple applications have stopped the hibernate from taking place."));
+
+		} else if (strcmp (action, "policy action") == 0) {
+			g_string_append (message, _("Multiple applications have stopped the policy action from taking place."));
+
+		} else if (strcmp (action, "reboot") == 0) {
+			g_string_append (message, _("Multiple applications have stopped the reboot from taking place.")); 
+
+		} else if (strcmp (action, "shutdown") == 0) {
+			g_string_append (message, _("Multiple applications have stopped the shutdown from taking place."));
+
+		} else if (strcmp (action, "timeout action") == 0) {
+			g_string_append (message, _("Multiple applications have stopped the suspend from taking place."));
+		}
+		
 		for (a=0; a<g_slist_length (inhibit->priv->list); a++) {
 			data = (GpmInhibitData *) g_slist_nth_data (inhibit->priv->list, a);
 			g_string_append_printf (message,
@@ -506,7 +553,7 @@ inhibit (DbusProxy       *gproxy,
 		g_error_free (error);
 		*cookie = 0;
 	}
-	if (ret == FALSE) {
+	if (!ret) {
 		/* abort as the DBUS method failed */
 		g_warning ("Inhibit failed!");
 	}
@@ -561,7 +608,7 @@ has_inhibit (DbusProxy *gproxy,
 		g_debug ("ERROR: %s", error->message);
 		g_error_free (error);
 	}
-	if (ret == FALSE) {
+	if (!ret) {
 		/* abort as the DBUS method failed */
 		g_warning ("HasInhibit failed!");
 	}
@@ -596,9 +643,9 @@ gpm_st_inhibit (GpmSelfTest *test)
 	/************************************************************/
 	gpm_st_title (test, "make sure we are not inhibited");
 	ret = has_inhibit (gproxy, &valid);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_failed (test, "Unable to test validity");
-	} else if (valid == TRUE) {
+	} else if (valid) {
 		gpm_st_failed (test, "Already inhibited");
 	} else {
 		gpm_st_success (test, NULL);
@@ -607,7 +654,7 @@ gpm_st_inhibit (GpmSelfTest *test)
 	/************************************************************/
 	gpm_st_title (test, "clear an invalid cookie");
 	ret = uninhibit (gproxy, 123456);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_success (test, "invalid cookie failed as expected");
 	} else {
 		gpm_st_failed (test, "should have rejected invalid cookie");
@@ -619,7 +666,7 @@ gpm_st_inhibit (GpmSelfTest *test)
 				  "gnome-power-self-test",
 				  "test inhibit",
 				  &cookie1);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_failed (test, "Unable to inhibit");
 	} else if (cookie1 == 0) {
 		gpm_st_failed (test, "Cookie invalid (cookie: %u)", cookie1);
@@ -630,9 +677,9 @@ gpm_st_inhibit (GpmSelfTest *test)
 	/************************************************************/
 	gpm_st_title (test, "make sure we are auto inhibited");
 	ret = has_inhibit (gproxy, &valid);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_failed (test, "Unable to test validity");
-	} else if (valid == TRUE) {
+	} else if (valid) {
 		gpm_st_success (test, "inhibited");
 	} else {
 		gpm_st_failed (test, "inhibit failed");
@@ -644,7 +691,7 @@ gpm_st_inhibit (GpmSelfTest *test)
 				  "gnome-power-self-test",
 				  "test inhibit",
 				  &cookie2);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_failed (test, "Unable to inhibit");
 	} else if (cookie2 == 0) {
 		gpm_st_failed (test, "Cookie invalid (cookie: %u)", cookie2);
@@ -655,7 +702,7 @@ gpm_st_inhibit (GpmSelfTest *test)
 	/************************************************************/
 	gpm_st_title (test, "clear cookie 1");
 	ret = uninhibit (gproxy, cookie1);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_failed (test, "cookie failed to clear");
 	} else {
 		gpm_st_success (test, NULL);
@@ -664,9 +711,9 @@ gpm_st_inhibit (GpmSelfTest *test)
 	/************************************************************/
 	gpm_st_title (test, "make sure we are still inhibited");
 	ret = has_inhibit (gproxy, &valid);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_failed (test, "Unable to test validity");
-	} else if (valid == TRUE) {
+	} else if (valid) {
 		gpm_st_success (test, "inhibited");
 	} else {
 		gpm_st_failed (test, "inhibit failed");
@@ -675,7 +722,7 @@ gpm_st_inhibit (GpmSelfTest *test)
 	/************************************************************/
 	gpm_st_title (test, "clear cookie 2");
 	ret = uninhibit (gproxy, cookie2);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_failed (test, "cookie failed to clear");
 	} else {
 		gpm_st_success (test, NULL);
